==> huaweicloudsdklts-3.1.96-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/delete_dashboard_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteDashboardRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'is_delete_charts': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'is_delete_charts': 'is_delete_charts'
    }

    def __init__(self, id=None, is_delete_charts=None):
        """DeleteDashboardRequest

        The model defined in huaweicloud sdk

        :param id: 仪表盘id
        :type id: str
        :param is_delete_charts: 是否删除图表
        :type is_delete_charts: bool
        """
        
        

        self._id = None
        self._is_delete_charts = None
        self.discriminator = None

        self.id = id
        self.is_delete_charts = is_delete_charts

    @property
    def id(self):
        """Gets the id of this DeleteDashboardRequest.

        仪表盘id

        :return: The id of this DeleteDashboardRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeleteDashboardRequest.

        仪表盘id

        :param id: The id of this DeleteDashboardRequest.
        :type id: str
        """
        self._id = id

    @property
    def is_delete_charts(self):
        """Gets the is_delete_charts of this DeleteDashboardRequest.

        是否删除图表

        :return: The is_delete_charts of this DeleteDashboardRequest.
        :rtype: bool
        """
        return self._is_delete_charts

    @is_delete_charts.setter
    def is_delete_charts(self, is_delete_charts):
        """Sets the is_delete_charts of this DeleteDashboardRequest.

        是否删除图表

        :param is_delete_charts: The is_delete_charts of this DeleteDashboardRequest.
        :type is_delete_charts: bool
        """
        self._is_delete_charts = is_delete_charts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteDashboardRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklts-3.1.158-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/delete_dashboard_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteDashboardRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'is_delete_charts': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'is_delete_charts': 'is_delete_charts'
    }

    def __init__(self, id=None, is_delete_charts=None):
        r"""DeleteDashboardRequest

        The model defined in huaweicloud sdk

        :param id: 仪表盘id
        :type id: str
        :param is_delete_charts: 是否删除图表
        :type is_delete_charts: bool
        """
        
        

        self._id = None
        self._is_delete_charts = None
        self.discriminator = None

        self.id = id
        self.is_delete_charts = is_delete_charts

    @property
    def id(self):
        r"""Gets the id of this DeleteDashboardRequest.

        仪表盘id

        :return: The id of this DeleteDashboardRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this DeleteDashboardRequest.

        仪表盘id

        :param id: The id of this DeleteDashboardRequest.
        :type id: str
        """
        self._id = id

    @property
    def is_delete_charts(self):
        r"""Gets the is_delete_charts of this DeleteDashboardRequest.

        是否删除图表

        :return: The is_delete_charts of this DeleteDashboardRequest.
        :rtype: bool
        """
        return self._is_delete_charts

    @is_delete_charts.setter
    def is_delete_charts(self, is_delete_charts):
        r"""Sets the is_delete_charts of this DeleteDashboardRequest.

        是否删除图表

        :param is_delete_charts: The is_delete_charts of this DeleteDashboardRequest.
        :type is_delete_charts: bool
        """
        self._is_delete_charts = is_delete_charts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteDashboardRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
